=======
Credits
=======

Development Lead
----------------

* Karthigayini Sivaprakasm (sivaprk@mskcc.org)

Contributors
------------

* Eric Buehler (buehlere@mskcc.org)
* Ronak Shah (shahr2@mskcc.org)
* Charlie Murphy <murphyc4@mskcc.org>
